#/#############################################################################\
## Ongeboren's script collection - Settings                                    #
## Copyright (C) 2002 - 2005 ongeboren <ongeboren@gmail.com>                   #
## Version: 2.1                                                                #
## Requires: XChat 2.0.8+                                                      #
## Distributed under the GPL license                                           #
#\#############################################################################/

###
# This is the configuration part of ongeboren's script collection.
# Each option is explained, but turned off by default.
# Failure to read the config, understand it and set it to work for you,
#  will simply make the whole script collection useless.
#
# There is a name convention for the script. All functions and variables
#  begin with a prepended 'onge_'. This way you are guaranteed to avoid
#  confusion with any other scripts.
#
# The use of other scripts that process and filter inbound privmsg and notices
#  in case you're going to use the single message window mode or the total
#  ignorer, can be the cause of confusion and could lead to messages being
#  wrongly blocked at the wrong time.
#  
###

################################################################################
# Single Message Window
###

###
# Use single message window for personal inbound notices and privmsgs if there
#  is no window/tab opened for a conversation with the person in question.
our $onge_set_single = 0;

###
# The tab where all private inbound messages will be redirected.
# This option is only applicable if $onge_set_single is set to non zero value.
# Note: Always prepend a '-' or other character a nickname may never start with.
#  If you choose a name for the tab that can coincide with a real nickname,
#  you will run into confusion if you will ever have to speak to that person!
our $onge_tabs_all = "-all";

###
# Do a /whois nick or /whois nick nick when you receive a private message out
#  of conversation mode - only triggers if there is no conversation window/tab.
# This option is only applicable if $onge_set_single is set to non zero value.
# The possible values are as follows:
#  1 -> do a /whois nick
#  2 -> do a /whois nick nick
our $onge_whois_on_private = 1;

###
# How many seconds to wait if you have issued a /whois command, before issueing
#  a new one? The minimum value is hardcoded to 1 and it is advised to have it
#  set to about 5. This will prevent /whois floods on multiple lines dumped to
#  you like for instance the output of help commands originating of irc services
#  you're querying for help. Keep it reasonable high in order to prevent other
#  /whois floods in case you receive a multiple clones flood attack or run into
#  somebody having same or similar script to yours.
our $onge_whois_interval = 5;

###
# You may aswel define a list of nicks that will be allowed to bypass the single
#  message window. Follow the example syntaxis.
# This option is only applicable if $onge_set_single is set to non zero value.
our @onge_single_bypass = ('ns', 'cs', 'gliner', 'seenserv', 'seen');

###
# Additionally you may want to explicitely create a query dialogue for the nicks
#  you specified in @onge_single_bypass. By default XChat displays private
#  notices in the first common tab you have with a given person. This is quite
#  annoying if you request information from ChanServ for instance via /msg
#  ChanServ in the current tab and you have to run through all other tabs in
#  order to find the reply.
# This option is only applicable if $onge_set_single is set to non zero value.
our $onge_query_on_bypass = 1;

################################################################################
# Basic Operator Settings
###

###
# Are you an irc operator? You can define here to auto-/oper on as many servers
#  as you like. You need to have the same password on each server.
$onge_set_oper = 0;

###
# The operator nickname or username - furst parameter of the /oper command.
$onge_oper_nick = "opernick";

###
# The password.
# Note that your computer must be secure. It is obviously stored as plain text.
$onge_oper_pass = "operpass";

###
# Specify operator-specific user modes that you would like to set after you get
#  /oper-ed .
$onge_oper_mode = "+ybfxcIS";

###
# Make a list of all servers where you would like to issue an /oper command when
#  connecting.
@onge_oper_serv = ("my.irc.server");

################################################################################
# Fancy Wallops Interface
###

###
# Use fancy wallops input/output?
our $onge_set_wallops = 0;

###
# The name of the wallops tab.
# Same considerations as the '-all' tab. Prepend a non-valid character like '-'.
our $onge_tabs_wall = "-wall";

###
# Use by default operwall (1) or locops (0) ?
# Beter keep it local, unless you don't care about saying incidentially or
#  unwillingly something stupid to a bunch of people.
our $onge_use_operwall = 0;

################################################################################
# Services G:lines Requests Filter
###

################################################################################
# Normal G:line Requesrs Filter
###

################################################################################
# Server Warning/Information Notices Filter
###

###
# Enable advanced server notices filter?
our $onge_set_snotice = 0;

###
# The name of the connecting/disconnecting tab.
# Same considerations as the "-all' tab. Prepend a non-valid character like '-'.
our $onge_tabs_conn = "-conn";

###
# Use a different tab for disconnecting client notices?
our $onge_exit_apart = 0;

###
# The name of the disconnecting tab.
# Applicable only if $onge_disconn_apart is non-zero.
# Same considerations as the "-all' tab. Prepend a non-valid character like '-'.
our $onge_tabs_disc = "-exit";

###
# Color for connecting users' notices.
our $onge_color_conn = 3;

###
# Color for exiting users' notices.
our $onge_color_exit = 4;

###
# K:line hosts, that fill up an I-line ?
our $onge_kline_ifull = 1;

###
# Time for the k:line in minutes if $onge_kline_ifull is defined.
our $onge_ktime_ifull = 120;

###
# K:line ident@host, that trigger a spambot warning ?
our $onge_kline_spam = 1;

###
# Time for the k:line in minutes if $onge_kline_spam id defined.
our $onge_ktime_spam = 120;

###
# Name of the klines tab.
# Same considerations as the "-all' tab. Prepend a non-valid character like '-'.
our $onge_tabs_kline = "-kli";

###
# Do a /whois nick or /whois nick nick when you receive a /whois.
# The possible values are as follows:
#  1 -> do a /whois nick
#  2 -> do a /whois nick nick
our $onge_whois_on_whois = 2;

###
# The name of the services glines requests tab.
# Same considerations as the "-all' tab. Prepend a non-valid character like '-'.
our $onge_tabs_gline = "-gli";

###
# List of gliners servers to ignore.
# Usually there are 3 psuedo servers for a gliner service. Define here the last
#  2 servers. The third one will not be ignored, or you may choose to ignore
#  them all, but this is imho a bad choice.
our @gliners_to_ignore = ( "SAN2.org", "SAN3.org",
													 "sockscleaner2.org", "sockscleaner3.org",
													 "psuedo2.org", "psuedo3.org" );

###
# Define pairs of gliners and mirc colors to display in $onge_tabs_gline
# This is CAsEsEnSitIVe!
# This must be the first server in the gliners servers trio.
our %gliners = ( "SAN1.org" => 10,
								 "sockscleaner1.org" => 7,
								 "psuedo1.org" => 8,);

###
# The name of the operators glines requests tab.
# Same considerations as the "-all' tab. Prepend a non-valid character like '-'.
our $onge_tabs_req = "-req";

###
# Hide "operator or server has already voted" messages for gline requests that
#  do match an existing gline on your server. This happens when another server
#  on the network rehashes its glines in order to let viruses, drones and
#  abusers into the network
# NB: If you intend to hide it, set it's value to just 1; you will be able to
#     see how many such lines were hidden by issuing /showhiddenvotes .
our $onge_hide_voted = 1;

################################################################################
# Miscelaneous Settings
###

###
# Color for info lines.
our $onge_color_info = 8;

Xchat::print( "\0033   Settings : loaded\003\n" );
1;
